Module options

Module options 

Connection options controlling connect and reconnect behavior.

Structs

ConnectOptions
ConnectOptions is used to configure the WebSocket connectivity behavior.

Enums

ConnectStrategy
ConnectionStrategy specifies how the WebSocket async fn connect() function should behave during the first-time connectivity phase. @category WebSocket

Constants

DEFAULT_CONNECT_RETRY_MILLIS
Default retry interval in milliseconds used when none is specified.
DEFAULT_CONNECT_TIMEOUT_MILLIS
Default connection timeout in milliseconds used when none is specified.