pub struct ConnectOptions {
pub block_async_connect: bool,
pub strategy: ConnectStrategy,
pub url: Option<String>,
pub connect_timeout: Option<Duration>,
pub retry_interval: Option<Duration>,
}Expand description
ConnectOptions is used to configure the WebSocket connectivity behavior.
@category WebSocket
Fields
block_async_connect: boolIndicates if the async fn connect() method should return immediately
or block until the connection is established.
strategy: ConnectStrategyConnectStrategy used to configure the retry or fallback behavior.
url: Option<String>Optional url that will change the current URL of the WebSocket.
Note that the URL overrides the use of resolver.
connect_timeout: Option<Duration>Optional timeout that will change the timeout of the WebSocket connection process.
Timeout is the period after which the async connection attempt is aborted. Timeout
is followed by the retry delay if the ConnectionStrategy is set to Retry.
retry_interval: Option<Duration>Retry interval denotes the time to wait before attempting to reconnect.
Implementations
Sourceimpl ConnectOptions
impl ConnectOptions
Sourcepub fn blocking_fallback() -> Self
pub fn blocking_fallback() -> Self
Options that block connect() until the first connection attempt
completes, returning on failure using ConnectStrategy::Fallback.
Sourcepub fn blocking_retry() -> Self
pub fn blocking_retry() -> Self
Options that block connect() until the connection is established,
continuously retrying using ConnectStrategy::Retry.
Sourcepub fn non_blocking_retry() -> Self
pub fn non_blocking_retry() -> Self
Options that return from connect() immediately while retrying
the connection in the background using ConnectStrategy::Retry.
Sourcepub fn with_url<S: Display>(self, url: S) -> Self
pub fn with_url<S: Display>(self, url: S) -> Self
Sets a custom URL that overrides the current WebSocket URL (and the resolver).
Sourcepub fn with_connect_timeout(self, timeout: Duration) -> Self
pub fn with_connect_timeout(self, timeout: Duration) -> Self
Sets the connection timeout after which a connection attempt is aborted.
Sourcepub fn with_retry_interval(self, interval: Duration) -> Self
pub fn with_retry_interval(self, interval: Duration) -> Self
Sets the retry interval to wait before attempting to reconnect.
Sourcepub fn connect_timeout(&self) -> Duration
pub fn connect_timeout(&self) -> Duration
Returns the configured connection timeout, or the default
(DEFAULT_CONNECT_TIMEOUT_MILLIS) if none was set.
Sourcepub fn retry_interval(&self) -> Duration
pub fn retry_interval(&self) -> Duration
Returns the configured retry interval, or the default
(DEFAULT_CONNECT_RETRY_MILLIS) if none was set.