WebSocketCounters

Struct WebSocketCounters 

pub struct WebSocketCounters {
    pub total_connections: Arc<AtomicUsize>,
    pub active_connections: Arc<AtomicUsize>,
    pub handshake_failures: Arc<AtomicUsize>,
    pub rx_bytes: Arc<AtomicUsize>,
    pub tx_bytes: Arc<AtomicUsize>,
}
Atomic counters that allow tracking connection counts and cumulative message sizes in bytes (bandwidth consumption without accounting for the websocket framing overhead). These counters can be created and supplied externally or supplied as None.

Fields

total_connections: Arc<AtomicUsize>

Cumulative number of connections accepted since startup.

active_connections: Arc<AtomicUsize>

Number of currently active (open) connections.

handshake_failures: Arc<AtomicUsize>

Cumulative number of connections that failed during handshake.

rx_bytes: Arc<AtomicUsize>

Total bytes received across all connections (excluding framing overhead).

tx_bytes: Arc<AtomicUsize>

Total bytes sent across all connections (excluding framing overhead).