Connection options controlling connect and reconnect behavior.
Structs
- Connect
Options ConnectOptionsis used to configure theWebSocketconnectivity behavior.
Enums
- Connect
Strategy ConnectionStrategyspecifies how the WebSocketasync fn connect()function should behave during the first-time connectivity phase. @category WebSocket
Constants
- DEFAULT_
CONNECT_ RETRY_ MILLIS - Default retry interval in milliseconds used when none is specified.
- DEFAULT_
CONNECT_ TIMEOUT_ MILLIS - Default connection timeout in milliseconds used when none is specified.